### -*- coding: utf-8 -*- ####################################################
##############################################################################
#
# Copyright (c) 2008-2013 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

__docformat__ = "restructuredtext"

# import standard packages
from fanstatic import Library, Resource, Group

# import Zope3 interfaces

# import local interfaces

# import Zope3 packages
from ztfy.blog.browser import ztfy_blog_front
from ztfy.bootstrap import ztfy_bootstrap, ztfy_bootstrap_css, ztfy_bootstrap_responsive_css
from ztfy.skin import ztfy_skin_base

# import local packages


library = Library('ztfy.bootstrap.blog', 'resources')

ztfy_bootstrap_blog_css = Resource(library, 'css/ztfy.bootstrap.blog.css',
                                   minified='css/ztfy.bootstrap.blog.min.css',
                                   depends=[ztfy_bootstrap_css])

ztfy_bootstrap_blog_responsive_css = Group(depends=[ztfy_bootstrap_blog_css,
                                                    ztfy_bootstrap_responsive_css])

ztfy_bootstrap_blog = Group(depends=[ztfy_skin_base,
                                     ztfy_blog_front,
                                     ztfy_bootstrap_blog_css,
                                     ztfy_bootstrap])

ztfy_bootstrap_blog_responsive = Group(depends=[ztfy_bootstrap_blog,
                                                ztfy_bootstrap_blog_responsive_css])



### -*- coding: utf-8 -*- ####################################################
##############################################################################
#
# Copyright (c) 2008-2013 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

__docformat__ = "restructuredtext"

# import standard packages
import copy

# import Zope3 interfaces
from zope.publisher.interfaces.browser import IBrowserSkinType

# import local interfaces
from ztfy.skin.interfaces import IDefaultView

# import Zope3 packages
from zope.component import queryUtility, queryMultiAdapter
from zope.publisher.browser import applySkin

# import local packages
from ztfy.skin.viewlet import ViewletBase


class LoginViewlet(ViewletBase):

    @property
    def manage_url(self):
        skin = queryUtility(IBrowserSkinType, 'ZTFY.BO')
        if skin is not None:
            fake = copy.copy(self.request)
            applySkin(fake, skin)
        else:
            fake = self.request
        adapter = queryMultiAdapter((self.context, fake, self.__parent__), IDefaultView)
        if adapter is not None:
            return adapter.getAbsoluteURL()



from setuptools import setup, find_packages
import os

DOCS = os.path.join(os.path.dirname(__file__),
                    'docs')

README = os.path.join(DOCS, 'README.txt')
HISTORY = os.path.join(DOCS, 'HISTORY.txt')
CONTRIBS = os.path.join(DOCS, 'CONTRIBUTORS.txt')

version = '0.1.3'
long_description = open(README).read() + '\n\n' + \
                   open(CONTRIBS).read() + '\n\n' + \
                   open(HISTORY).read()

tests_require = [
    'zope.testing',
]

setup(name='ztfy.bootstrap',
      version=version,
      description="Bootstrap based ZTFY skin",
      long_description=long_description,
      # Get more strings from
      # http://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Development Status :: 4 - Beta",
        "Framework :: Zope3",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Zope Public License",
        "Programming Language :: Python",
        "Topic :: Software Development :: User Interfaces"
        ],
      keywords='ZTFY bootstrap skin glyphicons',
      author='Thierry Florac',
      author_email='tflorac@ulthar.net',
      url='http://hg.ztfy.org/ztfy.bootstrap',
      license='zpl',
      packages=find_packages('src'),
      package_dir={'': 'src'},
      namespace_packages=['ztfy'],
      include_package_data=True,
      package_data={'': ['*.zcml', '*.txt', '*.pt', '*.pot', '*.po', '*.mo', '*.png', '*.gif', '*.jpeg', '*.jpg', '*.css', '*.js']},
      zip_safe=False,
      tests_require=tests_require,
      extras_require=dict(test=tests_require),
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
          'zope.component',
          'zope.i18nmessageid',
          'zope.interface',
          'ztfy.skin',
          'ztfy.utils',
      ],
      entry_points={
          'fanstatic.libraries': [
              'ztfy.bootstrap = ztfy.bootstrap:library',
              'ztfy.bootstrap.blog = ztfy.bootstrap.blog.skin:library'
          ]
      })



### -*- coding: utf-8 -*- ####################################################
##############################################################################
#
# Copyright (c) 2008-2013 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

__docformat__ = "restructuredtext"

# import standard packages
from fanstatic import Library, Resource, Group

# import Zope3 interfaces

# import local interfaces

# import Zope3 packages

# import local packages
from ztfy.jqueryui import jquery_17


from zope.i18nmessageid import MessageFactory
_ = MessageFactory('ztfy.bootstrap')


library = Library('ztfy.bootstrap', 'resources')

ztfy_bootstrap_css = Resource(library, 'css/bootstrap.css',
                              minified='css/bootstrap.min.css')

ztfy_bootstrap_responsive_css = Resource(library, 'css/bootstrap-responsive.css',
                                         minified='css/bootstrap-responsive.min.css',
                                         depends=[ztfy_bootstrap_css])

ztfy_bootstrap = Resource(library, 'js/bootstrap.js',
                          minified='js/bootstrap.min.js',
                          depends=[jquery_17, ztfy_bootstrap_css], bottom=True)

ztfy_bootstrap_responsive = Group(depends=[ztfy_bootstrap, ztfy_bootstrap_responsive_css])
